.. raw:: html

    <embed>
        <p align="center">
            <img width="300" src="https://github.com/yngtodd/pipe/blob/master/img/pylibrary.png">
        </p>
    </embed>

--------------------------

.. image:: https://badge.fury.io/py/pipe.png
    :target: http://badge.fury.io/py/pipe

.. image:: https://travis-ci.org/yngtodd/pipe.png?branch=master
    :target: https://travis-ci.org/yngtodd/pipe


=============================
Warp Pipe
=============================

Testbed for Tensorflow 2.0 TFX

Documentation
--------------
 
For references, tutorials, and examples check out our `documentation`_.

Installation
------------

From Sources:

You can either clone the public repository:

.. code-block:: console

    git clone git://github.com/yngtodd/pipe

Or download the `tarball`_:

.. code-block:: console

    curl  -OL https://github.com/yngtodd/pipe/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    python setup.py install

.. _tarball: https://github.com/yngtodd/pipe/tarball/master
.. _documentation: https://pipe.readthedocs.io/en/latest
